@@ -6,10 +6,10 @@ use std::path::{Path, PathBuf};
 use swc_atoms::js_word;
 use swc_common::{util::move_map::MoveMap, FileName, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms::{
-    fixer,
+use swc_ecma_transforms_base::{
+    fixer::fixer,
     helpers::{inject_helpers, HELPERS},
-    hygiene,
+    hygiene::hygiene,
 };
 use swc_ecma_utils::{find_ids, private_ident, ExprFactory};
 use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Node, Visit, VisitWith};
